# django-admin-framework

Modern way to build django admin panel

## Installation

Install using `pip`:

    pip install django-admin-framework

Add `'admin_framework'` to your `INSTALLED_APPS` setting:

    INSTALLED_APPS = [
        ...
        'admin_framework',
    ]
